# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 1
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtcoap-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtcoap       %mklibname qt%{qtmajor}coap %{qtmajor}
%define libqtcoap_d     %mklibname qt%{qtmajor}coap -d

Name:           qtcoap6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} CoAP component
License:        GPL-3.0-only WITH Qt-GPL-exception-1.0
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
#Source0:        https://github.com/qt/qtcoap/archive/v%%{version}/qtcoap-%%{version}.tar.gz
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

## upstreamable patches

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Network) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}

Provides:       qt%{qtmajor}-qtcoap = %{version}-%{release}

%description
Qt%{qtmajor} CoAP (API) provides classes and functions to access the CoAP protocol.

%files
%license LICENSES/*
%{_qt6_archdatadir}/sbom/qtcoap-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtCoap%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtCoap%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtcoap.qch
%{_qt6_docdir}/qtcoap/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtcoap}
Summary:        Qt%{qtmajor} Coap Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtcoap}
Qt%{qtmajor} Coap Component Library.

%files -n %{libqtcoap}
%license LICENSES/*
%{_qt6_libdir}/libQt6Coap.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtcoap_d}
Summary:        Devel files needed to build apps based on QtCoap
Group:          Development/KDE and Qt
Requires:       %{libqtcoap} = %{version}
Provides:       libqtcoap6-devel = %{version}
Provides:       libqt6coap-devel = %{version}
Provides:       qtcoap6-devel = %{version}
Provides:       qt6coap-devel = %{version}
Provides:       qt%{qtmajor}-qtcoap-devel = %{version}-%{release}

%description -n %{libqtcoap_d}
Devel files needed to build apps based on Qt Coap.

%files -n %{libqtcoap_d}
%{_qt6_includedir}/QtCoap/
%{_qt6_libdir}/libQt6Coap.so
%{_qt6_libdir}/cmake/Qt6Coap/
%{_qt6_libdir}/libQt6Coap.prl
%{_qt6_archdatadir}/mkspecs/modules/*.pri
%{_qt6_libdir}/qt6/modules/*.json
%{_qt6_libdir}/qt6/metatypes/qt6*_metatypes.json
%{_qt6_libdir}/pkgconfig/*.pc
%if %{with examples}
%{_qt6_examplesdir}/coap/
%endif
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtCoapTestsConfig.cmake

#------------------------------------------------------------------------------

%prep
%autosetup -n qtcoap-everywhere-src-%{qtversion}

%build
%cmake_qt6 \
        %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF} \
        %{!?with_examples:-DQT_INSTALL_EXAMPLES_SOURCES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif


%changelog
* Wed Dec 18 2024 daviddavid <daviddavid> 6.8.1-1.mga10
+ Revision: 2125943
- New version 6.8.1

* Sun Oct 06 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103679
- New version 6.7.3
- enable docs building

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083100
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072753
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Wed May 22 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2065873
- New version 6.7.1

* Wed Apr 03 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2054159
- initial package qtcoap6

